@@ -76,7 +76,7 @@ PF_effective_sample_size <- function(object){
 #' The function is still under development so the output and API may change.
 #'
 #' @examples
-#'\dontrun{
+#' \donttest{
 #'#####
 #'# Fit model with lung data set from survival
 #'# Warning: long-ish computation time
@@ -94,9 +94,10 @@ PF_effective_sample_size <- function(object){
 #'  Q_0 = diag(1, 2), Q = diag(.5^2, 2),
 #'  max_T = 800,
 #'  control = PF_control(
-#'     N_fw_n_bw = 500, N_first = 2500, N_smooth = 5000,
+#'     # these number should be larger! Small for CRAN checks
+#'     N_fw_n_bw = 100L, N_first = 250L, N_smooth = 100L,
 #'     n_max = 50, eps = .001, Q_tilde = diag(.2^2, 2), est_a_0 = FALSE,
-#'     n_threads = max(parallel::detectCores(logical = FALSE), 1)))
+#'     n_threads = 2))
 #'
 #'# Plot state vector estimates
 #'plot(pf_fit, cov_index = 1)
@@ -105,7 +106,7 @@ PF_effective_sample_size <- function(object){
 #'# Plot log-likelihood
 #'plot(pf_fit$log_likes)
 #'}
-#'\dontrun{
+#' \donttest{
 #'######
 #'# example with fixed intercept
 #'
@@ -144,11 +145,12 @@ PF_effective_sample_size <- function(object){
 #'   by = 100, id = pbc2$id,
 #'   model = "exponential", max_T = 3600,
 #'   control = PF_control(
-#'     N_fw_n_bw = 500, N_smooth = 2500, N_first = 1000, eps = 1e-3,
+#'     # these number should be larger! Small for CRAN checks
+#'     N_fw_n_bw = 100, N_smooth = 250, N_first = 100, eps = 1e-3,
 #'     method = "AUX_normal_approx_w_cloud_mean", est_a_0 = FALSE,
 #'     Q_tilde = as.matrix(.1^2),
 #'     n_max = 25, # just take a few iterations as an example
-#'     n_threads = max(parallel::detectCores(logical = FALSE), 1)))
+#'     n_threads = 2))
 #'
 #'# compare results
 #'plot(ddfit)
@@ -157,7 +159,7 @@ PF_effective_sample_size <- function(object){
 #'sqrt(pf_fit$Q)
 #'rbind(ddfit$fixed_effects, pf_fit$fixed_effects)
 #'}
-#'\dontrun{
+#' \donttest{
 #' #####
 #' # simulation example with `random` and `fixed` argument and a restricted
 #' # model
@@ -264,35 +266,35 @@ PF_effective_sample_size <- function(object){
 #'     N_fw_n_bw = 100L, N_smooth = 100L, N_first = 500L,
 #'     method = "AUX_normal_approx_w_cloud_mean",
 #'     nu = 5L, # sample from multivariate t-distribution
-#'     n_max = 100L,  averaging_start = 50L,
+#'     n_max = 60L,  averaging_start = 50L,
 #'     smoother = "Fearnhead_O_N", eps = 1e-4, covar_fac = 1.2,
-#'     n_threads = 4L # depends on your cpu(s)
+#'     n_threads = 2L # depends on your cpu(s)
 #'   ),
 #'   trace = 1L)
 #' plot(fit$log_likes) # log-likelihood approximation at each iterations
 #'
-#' # take more iterations with more particles
-#' cl <- fit$call
-#' ctrl <- cl[["control"]]
-#' ctrl[c("N_fw_n_bw", "N_smooth", "N_first", "n_max",
-#'        "averaging_start")] <- list(500L, 2000L, 5000L, 200L, 30L)
-#' cl[["control"]] <- ctrl
-#' cl[c("phi", "psi", "theta")] <- list(fit$phi, fit$psi, fit$theta)
-#' fit_extra <- eval(cl)
+#' # you can take more iterations by uncommenting the following
+#' # cl <- fit$call
+#' # ctrl <- cl[["control"]]
+#' # ctrl[c("N_fw_n_bw", "N_smooth", "N_first", "n_max",
+#' #        "averaging_start")] <- list(500L, 2000L, 5000L, 200L, 30L)
+#' # cl[["control"]] <- ctrl
+#' # cl[c("phi", "psi", "theta")] <- list(fit$phi, fit$psi, fit$theta)
+#' # fit_extra <- eval(cl)
 #'
-#' plot(fit_extra$log_likes) # log-likelihood approximation at each iteration
+#' plot(fit$log_likes) # log-likelihood approximation at each iteration
 #'
 #' # check estimates
-#' sqrt(diag(fit_extra$Q))
+#' sqrt(diag(fit$Q))
 #' sqrt(diag(Q))
-#' cov2cor(fit_extra$Q)
+#' cov2cor(fit$Q)
 #' cov2cor(Q)
-#' fit_extra$F
+#' fit$F
 #' F.
 #'
 #' # plot predicted state variables
 #' for(i in 1:p){
-#'   plot(fit_extra, cov_index = i)
+#'   plot(fit, cov_index = i)
 #'   abline(h = 0, lty = 2)
 #'   lines(1:nrow(alphas) - 1, alphas[, i] - beta[i], lty = 3)
 #' }
@@ -553,7 +555,7 @@ PF_EM <- function(
 #' The function is still under development so the output and API may change.
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' # head-and-neck cancer study data. See Efron, B. (1988) doi:10.2307/2288857
 #' is_censored <- c(
 #'   6, 27, 34, 36, 42, 46, 48:51, 51 + c(15, 30:28, 33, 35:37, 39, 40, 42:45))
@@ -574,7 +576,7 @@ PF_EM <- function(
 #' ctrl <- PF_control(
 #'   N_fw_n_bw = 500, N_smooth = 2500, N_first = 2000,
 #'   n_max = 1, # set to one as an example
-#'   n_threads = max(parallel::detectCores(logical = FALSE), 1),
+#'   n_threads = 2,
 #'   eps = .001, Q_tilde = as.matrix(.3^2), est_a_0 = FALSE)
 #' pf_fit <- suppressWarnings(
 #'   PF_EM(
@@ -726,12 +728,12 @@ PF_forward_filter.data.frame <- function(
     # set the seed
     old_seed <- .GlobalEnv$.Random.seed
     # to make sure the user has the same `rng.kind`
-    on.exit(.GlobalEnv$.Random.seed <- old_seed)
+    on.exit(assign(".Random.seed", old_seed, envir = .GlobalEnv))
 
     stopifnot(length(seed) > 1) # make sure user did not use seed as in
     # `set.seed`
     if(control$fix_seed)
-      .GlobalEnv$.Random.seed <- seed
+      assign(".Random.seed", seed, envir = .GlobalEnv)
   }
 
   out <- particle_filter(
@@ -740,7 +742,7 @@ PF_forward_filter.data.frame <- function(
     fixed_terms = static_args$fixed_terms, tstart = static_args$tstart,
     tstop = static_args$tstop, risk_obj = static_args$risk_obj,
     debug = static_args$debug, model = static_args$model, Q = Q, Q_0 = Q_0,
-    F = Fmat, R = R, is_forward = TRUE, a_0 = a_0, N_fw_n_bw = N_fw,
+    Fmat = Fmat, R = R, is_forward = TRUE, a_0 = a_0, N_fw_n_bw = N_fw,
     N_first = N_first, nu = if(is.null(control$nu)) 0L else control$nu,
     forward_backward_ESS_threshold = control$forward_backward_ESS_threshold,
     method = control$method, n_threads = control$n_threads, Q_tilde = Q_tilde,
@@ -780,14 +782,14 @@ get_Q_tilde <- function(x, n_vars)
     !is.null(G), !is.null(J), !is.null(K), !is.null(theta), !is.null(psi),
     !is.null(phi))
   if(is_restricted){
-    fit_call[["F"]]   <- F. <- .get_F(G, theta)
+    fit_call[["Fmat"]]   <- F. <- .get_F(G, theta)
     fit_call[["Q"]]   <- Q  <- .get_Q(J, K, psi, phi)$Q
     fit_call[["a_0"]] <- eval(fit_call[["a_0"]], parent.frame())
     G_tilde <- .get_cum_mat(nrow(F.), ncol(F.)) %*% G
     J_qr <- qr(J)
 
   } else {
-    fit_call[["F"]]   <- eval(fit_call[["F."]] , parent.frame())
+    fit_call[["Fmat"]]   <- eval(fit_call[["F."]] , parent.frame())
     fit_call[["a_0"]] <- eval(fit_call[["a_0"]], parent.frame())
     fit_call[["Q"]]   <- eval(fit_call[["Q"]]  , parent.frame())
 
@@ -799,18 +801,18 @@ get_Q_tilde <- function(x, n_vars)
   # print Q and F structure
   if(trace > 0 && is_restricted){
     tmp <- list(
-      F = .get_F(G, seq_along(theta)), R = R,
+      Fmat = .get_F(G, seq_along(theta)), R = R,
       Q = .get_Q(J, K, seq_along(psi), seq_along(phi))$Q)
     tmp <- .set_PF_names(tmp, rng_names = row.names(X), fixed_names = NULL)
 
     # start with F
     if(all(rowSums(G) < 2, G %in% c(0, 1))){
-      tmp$F <- structure(
-        sapply(tmp$F, sprintf, fmt = "t%d"), dimnames = dimnames(tmp$F),
-        dim = dim(tmp$F))
-      tmp$F[tmp$F == "t0"] <- NA_character_
+      tmp$Fmat <- structure(
+        sapply(tmp$Fmat, sprintf, fmt = "t%d"), dimnames = dimnames(tmp$F),
+        dim = dim(tmp$Fmat))
+      tmp$Fmat[tmp$Fmat == "t0"] <- NA_character_
       cat(sQuote("F"), "matrix is of the following form\n")
-      print(tmp$F, quote = FALSE, na.print = "")
+      print(tmp$Fmat, quote = FALSE, na.print = "")
       cat("\n")
 
     }
@@ -880,7 +882,7 @@ get_Q_tilde <- function(x, n_vars)
       }
       if(type == "VAR"){
         cat("F is:\n")
-        print(fit_call$F)
+        print(fit_call$Fmat)
       }
 
       print_covmat(fit_call$Q, "Q")
@@ -924,13 +926,13 @@ get_Q_tilde <- function(x, n_vars)
       cat("Updating parameters in state model...\n")
     a_0_old <- fit_call$a_0
     Q_old <- fit_call$Q
-    F_old <- fit_call$F
+    F_old <- fit_call$Fmat
     fixed_params_old <- fixed_params
 
     if(type == "RW"){
       sum_stats <- compute_PF_summary_stats(
         clouds, n_threads, a_0 = a_0, Q = Q, Q_0 = Q_0, R = R,
-        debug = trace > 2, F = F.)
+        debug = trace > 2, Fmat = F.)
       if(est_a_0)
         a_0 <- drop(sum_stats[[1]]$E_xs)
       Q <- Reduce(
@@ -956,13 +958,13 @@ get_Q_tilde <- function(x, n_vars)
           G_tilde, kronecker(solve(Q), crossprod(QR_R)) %*% G_tilde)
         theta <- drop(solve(t2, t1))
         # TODO: need to change for higher order models
-        fit_call$F <- F. <- .get_F(G, theta)
+        fit_call$Fmat <- F. <- .get_F(G, theta)
 
         if(trace > 0)
           cat("Running second conditional maximization step\n")
         sum_stats <- compute_PF_summary_stats(
           clouds, n_threads, a_0 = a_0, Q = Q, Q_0 = Q_0, R = R,
-          debug = trace > 2, F = F., do_use_F = TRUE, do_compute_E_x = FALSE)
+          debug = trace > 2, Fmat = F., do_use_F = TRUE, do_compute_E_x = FALSE)
         Z <- Reduce(
           "+", lapply(sum_stats, "[[", "E_x_less_x_less_one_outers"))
 
@@ -1036,7 +1038,7 @@ get_Q_tilde <- function(x, n_vars)
           clouds, n_threads, a_0 = a_0, Q = Q, Q_0 = Q_0, R = R,
           debug = trace > 1, only_QR = FALSE)
         # TODO: need to change for higher order models
-        fit_call$F <- F. <- new_params$R_top_F
+        fit_call$Fmat <- F. <- new_params$R_top_F
         fit_call$Q <- Q <- new_params$Q
 
       }
@@ -1083,13 +1085,13 @@ get_Q_tilde <- function(x, n_vars)
         fit_call$fixed_params <- fixed_params <- colMeans(
           fixed_params_it[avg_idx, , drop = FALSE])
 
-      fit_call$F <- F. <- apply(F_it[, , avg_idx, drop = FALSE], 1:2, mean)
-      fit_call$Q <- Q  <- apply(Q_it[, , avg_idx, drop = FALSE], 1:2, mean)
+      fit_call$Fmat <- F. <- apply(F_it[, , avg_idx, drop = FALSE], 1:2, mean)
+      fit_call$Q    <- Q  <- apply(Q_it[, , avg_idx, drop = FALSE], 1:2, mean)
 
     }
 
     if(type == "VAR")
-      Q_0 <- fit_call$Q_0 <- get_Q_0(Qmat = fit_call$Q, Fmat = fit_call$F)
+      Q_0 <- fit_call$Q_0 <- get_Q_0(Qmat = fit_call$Q, Fmat = fit_call$Fmat)
 
     # compute norms
     Q_relative_norm <- norm(Q_old - Q) / (norm(Q_old) + 1e-8)
@@ -1136,7 +1138,7 @@ get_Q_tilde <- function(x, n_vars)
 
   out <- structure(list(
     call = cl, clouds = clouds, a_0 = a_0, fixed_effects = fixed_params, Q = Q,
-    F = fit_call$F, R = R, EM_ests = list(
+    F = fit_call$Fmat, R = R, EM_ests = list(
       a_0             = a_0_it         [1:i, , drop = FALSE],
       fixed_effects   = fixed_params_it[1:i, , drop = FALSE],
       F = F_it[, , 1:i, drop = FALSE],
@@ -1632,7 +1634,7 @@ get_cloud_quantiles.PF_clouds <- function(
 #' \code{FALSE}.}
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' library(dynamichazard)
 #' .lung <- lung[!is.na(lung$ph.ecog), ]
 #' # standardize
@@ -1649,7 +1651,7 @@ get_cloud_quantiles.PF_clouds <- function(
 #'   control = PF_control(
 #'     N_fw_n_bw = 250, N_first = 2000, N_smooth = 500, covar_fac = 1.1,
 #'     nu = 6, n_max = 1000L, eps = 1e-4, averaging_start = 200L,
-#'     n_threads = max(parallel::detectCores(logical = FALSE), 1)))
+#'     n_threads = 2))
 #'
 #' # compute score and observed information matrix
 #' comp_obj <- PF_get_score_n_hess(pf_fit)
@@ -1745,7 +1747,7 @@ PF_get_score_n_hess <- function(object, debug = FALSE, use_O_n_sq = FALSE){
       fixed_terms = static_args$fixed_terms, tstart = static_args$tstart,
       tstop = static_args$tstop, risk_obj = static_args$risk_obj,
       debug = debug, model = static_args$model, Q = Q, Q_0 = Q_0,
-      F = Fmat, R = R, is_forward = TRUE, a_0 = a_0, N_fw_n_bw = N_fw,
+      Fmat = Fmat, R = R, is_forward = TRUE, a_0 = a_0, N_fw_n_bw = N_fw,
       N_first = N_first, nu = if(is.null(ctrl$nu)) 0L else ctrl$nu,
       forward_backward_ESS_threshold = ctrl$forward_backward_ESS_threshold,
       method = ctrl$method, n_threads = ctrl$n_threads, Q_tilde = Q_tilde,
@@ -1785,7 +1787,7 @@ PF_get_score_n_hess <- function(object, debug = FALSE, use_O_n_sq = FALSE){
     if(ctrl$fix_seed)
       assign(".Random.seed", seed, envir = .GlobalEnv)
     cpp_res <- PF_get_score_n_hess_cpp(
-      fw_cloud = fw_cloud, Q = Q, F = Fmat,
+      fw_cloud = fw_cloud, Q = Q, Fmat = Fmat,
       risk_obj = static_args$risk_obj, ran_vars = static_args$X,
       fixed_terms = static_args$fixed_terms, tstart = static_args$tstart,
       tstop = static_args$tstop, fixed_params = fixed_effects,
